@@ -13,6 +13,7 @@ from natsort import natsorted
 from .models import *
 from .util import *
 from . import cache
+from . import config as g_config
 
 # Figure out where this script is, and change the PATH appropriately
 BASE = os.path.abspath(os.path.dirname(sys.modules[__name__].__file__))
@@ -32,6 +33,9 @@ config = {}
 nodes = {}
 clusters = {}
 
+# Disable unverified HTTPS warnings - we know what we're doing
+requests.packages.urllib3.disable_warnings()
+
 
 
 def load_modules():
@@ -105,8 +109,13 @@ def open_config():
 def load_config(f):
 	'''Loads configuration data from a given file.'''
 	
-	conf = json.load(f, encoding='utf-8')
+	try:
+		conf = json.load(f, encoding='utf-8')
+	except ValueError as e:
+		sys.exit("Configuration Syntax Error: " + str(e))
+	
 	f.close()
+	g_config.config.update(conf)
 	return conf
 
 def process_config(config, preload_wsdl=False):
@@ -114,9 +123,9 @@ def process_config(config, preload_wsdl=False):
 	
 	nodes = { name: Node(data, name) for name, data in config.get('nodes', {}).iteritems() }
 	clusters = {}
-
+	
 	if preload_wsdl:
-		download_wsdl(nodes.itervalues())
+		download_wsdl(nodes.itervalues(), verify=config.get('verify_ssl', True))
 		async_dispatch({ node: (node.load_wsdl,) for node in nodes.itervalues() })
 	
 	for name, data in config.get('clusters', {}).iteritems():
@@ -125,6 +134,8 @@ def process_config(config, preload_wsdl=False):
 		cluster.load_data(data)
 		
 		for nid in data['nodes'] if isinstance(data, dict) else data:
+			if not nid in nodes:
+				sys.exit("Configuration Error: Cluster '{cid}' references nonexistent node '{nid}'".format(cid=cluster.name, nid=nid))
 			node = nodes[nid]
 			node.cluster = cluster
 			cluster.append(node)
@@ -154,20 +165,23 @@ def apply_filter(available_nodes, available_clusters, nodes, clusters, slice_=''
 	
 	return NodeList(natsorted(targets, key=lambda t: [t.cluster.name, t.name]))
 
-def download_wsdl(nodes):
+def download_wsdl(nodes, verify):
 	path = cache.get_path('wsdl.xml')
 	min_mtime = arrow.utcnow().replace(hours=-12)
 	if not os.path.exists(path) or arrow.get(os.path.getmtime(path)) < min_mtime:
 		has_been_downloaded = False
 		for node in nodes:
 			try:
-				r = requests.get("{scheme}://{host}/remote/?wsdl".format(scheme=node.scheme, host=node.host), stream=True)
+				r = requests.get("{scheme}://{host}/remote/?wsdl".format(scheme=node.scheme, host=node.host), stream=True, verify=verify)
 				if r.status_code == 200:
 					with open(path, 'wb') as f:
 						for chunk in r.iter_content(256):
 							f.write(chunk)
 					has_been_downloaded = True
 					break
+			except requests.exceptions.SSLError:
+				print_ssl_error(node)
+				sys.exit(1)
 			except:
 				pass
 		
